/************************************************************************/
/*                                                                      */
/*      Calendar Tweaks  -  Thunderbird Extension  -  Calendar Views    */
/*                                                                      */
/*      Javascript for Calendar Views overlay                           */
/*                                                                      */
/*      Copyright (C) 2008-2011  by  DW-dev                             */
/*                                                                      */
/*      Last Edit  -  28 Dec 2011                                       */
/*                                                                      */
/************************************************************************/

var calendarTweaks =
{
    appInfo: Components.classes["@mozilla.org/xre/app-info;1"].getService(Components.interfaces.nsIXULAppInfo),
    versionComparator: Components.classes["@mozilla.org/xpcom/version-comparator;1"].getService(Components.interfaces.nsIVersionComparator),
    tbVersion: "",

    prefs: Components.classes["@mozilla.org/preferences-service;1"].getService(Components.interfaces.nsIPrefService).getBranch("extensions.calendartweaks."),
    
    SSServ: Components.classes["@mozilla.org/content/style-sheet-service;1"].getService(Components.interfaces.nsIStyleSheetService),
    IOServ: Components.classes["@mozilla.org/network/io-service;1"].getService(Components.interfaces.nsIIOService),

    selectedDay: null,

    /************************************************************************/

    /* Listen for changes to settings */

    prefsObserver:
    {
        register: function()
        {
            /* Query nsIPrefBranch2 interface to observe changes to pref values */
            calendarTweaks.prefs.QueryInterface(Components.interfaces.nsIPrefBranch2);

            /* Add the observer */
            calendarTweaks.prefs.addObserver("",this,false);
        },

        observe: function(subject,topic,data)
        {
            if (topic != "nsPref:changed") return;
            
            calendarTweaks.calendarViews();
        }
    },

    /************************************************************************/

    /* Load function */

    onLoad: function()
    {
        window.removeEventListener("load",calendarTweaks.onLoad,false);
        
        /* Determine Thunderbird version */
        
        if (calendarTweaks.versionComparator.compare(calendarTweaks.appInfo.version,"8.0b1") >= 0) calendarTweaks.tbVersion = "8.0";
        else if (calendarTweaks.versionComparator.compare(calendarTweaks.appInfo.version,"5.0b1") >= 0) calendarTweaks.tbVersion = "5.0";
        else calendarTweaks.tbVersion = "3.1";
        
        document.getElementById("messengerWindow").setAttribute("calendartweaks-tbversion",calendarTweaks.tbVersion);
        
        /* Style calendar views */
        
        calendarTweaks.calendarViews();
    },

    /************************************************************************/

    /* Calendar styling function */

    calendarViews: function()
    {
        var uri,element;
        
        /* Remove all bindings (if present) */
        
        uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-todayselday-alldaylabel-bindings.css", null, null);
        if (calendarTweaks.SSServ.sheetRegistered(uri,calendarTweaks.SSServ.USER_SHEET)) calendarTweaks.SSServ.unregisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        
        uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-todayselday-bindings.css", null, null);
        if (calendarTweaks.SSServ.sheetRegistered(uri,calendarTweaks.SSServ.USER_SHEET)) calendarTweaks.SSServ.unregisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        
        uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-alldaylabel-bindings.css", null, null);
        if (calendarTweaks.SSServ.sheetRegistered(uri,calendarTweaks.SSServ.USER_SHEET)) calendarTweaks.SSServ.unregisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        
        uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-repeating-bindings.css", null, null);
        if (calendarTweaks.SSServ.sheetRegistered(uri,calendarTweaks.SSServ.USER_SHEET)) calendarTweaks.SSServ.unregisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);

        /* Load bindings for: */
        /* Show Today and Selected Day on Day View */
        /* Add Label for All Day Events Row/Column */
        
        if (calendarTweaks.prefs.getBoolPref("todayselday") && calendarTweaks.prefs.getBoolPref("alldaylabel"))
        {
            uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-todayselday-alldaylabel-bindings.css", null, null);
            calendarTweaks.SSServ.loadAndRegisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        }
        else if (calendarTweaks.prefs.getBoolPref("todayselday"))
        {
            uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-todayselday-bindings.css", null, null);
            calendarTweaks.SSServ.loadAndRegisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        }
        else if (calendarTweaks.prefs.getBoolPref("alldaylabel"))
        {
            uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-alldaylabel-bindings.css", null, null);
            calendarTweaks.SSServ.loadAndRegisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        }
        
        /* Load bindings for: */
        /* Indicate Repeating Events */
        
        if (calendarTweaks.prefs.getBoolPref("repeatnormal") || calendarTweaks.prefs.getBoolPref("repeatexcept"))
        {
            uri = calendarTweaks.IOServ.newURI("chrome://calendartweaks/skin/calendartweaks-calendar-views-repeating-bindings.css", null, null);
            calendarTweaks.SSServ.loadAndRegisterSheet(uri,calendarTweaks.SSServ.USER_SHEET);
        }

        /* New Today and Selected Day */
        
        if (calendarTweaks.prefs.getBoolPref("newtoday"))
        {
            element = document.getElementById("calMinimonth");
            element.setAttribute("calendartweaks-newtoday","");
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-newtoday","");
        }
        else
        {
            element = document.getElementById("calMinimonth");
            element.removeAttribute("calendartweaks-newtoday");
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-newtoday");
        }
          
        if (calendarTweaks.prefs.getBoolPref("newselday"))
        {
            element = document.getElementById("calMinimonth");
            element.setAttribute("calendartweaks-newselday","");
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-newselday","");
        }
        else
        {
            element = document.getElementById("calMinimonth");
            element.removeAttribute("calendartweaks-newselday");
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-newselday");
        }
       
        /* Repeating Events */
        
        if (calendarTweaks.prefs.getBoolPref("repeatnormal"))
        {
            /* necessary bindings are loaded in calendarTweaks.loadBindings() */
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-repeatnormal","");
        }
        else
        {
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-repeatnormal");
        }
         
        if (calendarTweaks.prefs.getBoolPref("repeatexcept"))  
        {
            /* necessary bindings are loaded in calendarTweaks.loadBindings() */
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-repeatexcept","");
        }
        else
        {
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-repeatexcept");
        }
        
        /* Miscellaneous */
        
        if (calendarTweaks.prefs.getBoolPref("eventborder"))
        {
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-eventborder","");
        }
        else
        {
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-eventborder");
        }
        
        if (calendarTweaks.prefs.getBoolPref("datelabelbkgd"))
        {
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-datelabelbkgd","");
        }
        else
        {
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-datelabelbkgd");
        }
          
        if (calendarTweaks.prefs.getBoolPref("lightshadeother"))
        {
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-lightshadeother","");
        }
        else
        {
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-lightshadeother");
        }
       
        if (calendarTweaks.prefs.getBoolPref("alldaylabel"))
        {
            /* necessary bindings are loaded in calendarTweaks.loadBindings() */
            element = document.getElementById("view-deck");
            element.setAttribute("calendartweaks-alldaylabel","");
        }
        else
        {
            element = document.getElementById("view-deck");
            element.removeAttribute("calendartweaks-alldaylabel");
        }
        
        /* Refresh Display */
        
        calendarTweaks.selectedDay = currentView().selectedDay;
        
        currentView().setSelectedItems(0,[],true);
        
        window.setTimeout(calendarTweaks.refresh,10);
    },

    refresh: function()
    {
        switch (+getViewDeck().selectedIndex)
        {
            case 0: switchToView('day'); break;
            case 1: switchToView('week'); break;
            case 2: switchToView('multiweek'); break;
            case 3: switchToView('month'); break;
        }

        currentView().goToDay(calendarTweaks.selectedDay);
    }
};

window.addEventListener("load",calendarTweaks.onLoad,false);

calendarTweaks.prefsObserver.register();
